==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/LibraryBrowser/ts/LibraryBrowser_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>LibraryBrowser</name>
    <message>
        <location filename="../LibraryBrowser.js" line="+69"/>
        <source>audience</source>
        <translation>občinstvo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>creator</source>
        <translation>avtor</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>dimension</source>
        <translation>dimenzija</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>levelOfDetail</source>
        <translation>nivo podrobnosti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>license</source>
        <translation>licenca</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>perspective</source>
        <translation>pogled</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>presentation</source>
        <translation>predstavitev</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>publisher</source>
        <translation>izdajatelj</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>subject</source>
        <translation>zadeva</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>title</source>
        <translation>naslov</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Widgets</source>
        <translation>Gradniki</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1105"/>
        <location filename="../LibraryBrowserInit.js" line="+18"/>
        <source>Library Browser</source>
        <translation>Brskalnik po knjižnici</translation>
    </message>
    <message>
        <location line="-1097"/>
        <source>Icon</source>
        <translation>Ikona</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>List</source>
        <translation>Seznam</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Choose Source Folder</source>
        <translation>Izberite izvorno mapo</translation>
    </message>
    <message>
        <location line="+652"/>
        <source>Page %1 of %2</source>
        <translation>Stran %1 od %2</translation>
    </message>
    <message>
        <location line="+219"/>
        <source>Updating icons...</source>
        <translation>Posodabljam ikone...</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+219"/>
        <source>Abort</source>
        <translation>Prekini</translation>
    </message>
    <message>
        <location line="-27"/>
        <source>File:</source>
        <translation>Datoteka:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Folder:</source>
        <translation>Mapa:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>License:</source>
        <translation>Licenca:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attribute as:</source>
        <translation>Atribut kot:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Creator:</source>
        <translation>Avtor:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Updating library index:</source>
        <translation>Posodabljam index knjižnice:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>DB error</source>
        <translation>Napaka podatkovne baze</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</source>
        <translation>Vtičnik LibraryBrowser: Nemorem se povezat na podatkovno bazo.
Napaka gonilnika: %1
Napaka na baze: %2
Datoteka baze: %3
Vtičnik LibraryBrowser ne bo navoljo.</translation>
    </message>
    <message>
        <location line="+446"/>
        <source>&amp;Insert</source>
        <translation>&amp;Vstavi</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Edit Script File...</source>
        <translation>&amp;Uredi datoteko skripte...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Open &amp;SVG File...</source>
        <translation>Odpri &amp;SVG datoteko...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Open...</source>
        <translation>&amp;Odpri...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;Edit...</source>
        <translation>&amp;Uredi...</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>File Browser</source>
        <translation>Brskalnik datotek</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Show in %1...</source>
        <translation>P&amp;rikaži v %1...</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>&amp;Remove from Favorites</source>
        <translation>Izbriši iz pri&amp;ljubljenih</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Add to Favorites</source>
        <translation>Dodaj med &amp;priljubljene</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>&amp;Regenerate Icon</source>
        <translation>&amp;Osveži ikono</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Regenerate Icons</source>
        <translation>&amp;Osveži ikone</translation>
    </message>
    <message>
        <location filename="../LibraryBrowserInit.js" line="-10"/>
        <source>&amp;Library Browser</source>
        <translation>Brskalnik po &amp;knjižnici</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Synchronization</source>
        <translation>Sinhronizacija</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Update search index on startup</source>
        <translation>Posodobi iskalni index ob zagonu</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display Options</source>
        <translation>Nastavitve prikaza</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Icon Size:</source>
        <translation>Velikost ikone:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>View Mode:</source>
        <translation>Način pogleda:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Number of items
shown in search results:</source>
        <translation>Število predmetov,
 prikazanih v rezultatih iskanja:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Library Sources</source>
        <translation>Viri knjižni</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Add...</source>
        <translation>Dodaj...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Remove</source>
        <translation>Odstrani</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Up</source>
        <translation>Gor</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Down</source>
        <translation>Dol</translation>
    </message>
</context>
<context>
    <name>LibraryBrowserForm</name>
    <message>
        <location filename="../LibraryBrowser.ui" line="+28"/>
        <source>File System</source>
        <translation>Datotečni sistem</translation>
    </message>
    <message>
        <location line="+51"/>
        <source>Tags</source>
        <translation>Značke</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Look for:</source>
        <translation>Išči za:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Clear</source>
        <translation>Počisti</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Find</source>
        <translation>Najdi</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Reset tag selection</source>
        <translation>Ponastavi izbor značk</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>about:blank</source>
        <translation>o:nedoločeno</translation>
    </message>
    <message>
        <location line="+106"/>
        <source>Favorites</source>
        <translation>Priljubljeno</translation>
    </message>
    <message>
        <location line="+51"/>
        <source>Update DB from file system</source>
        <translation>Posodobi podatkovno bazo iz datoteke</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>0</source>
        <translation>0</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/LibraryBrowser/ts/LibraryBrowser_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>LibraryBrowser</name>
    <message>
        <location filename="../LibraryBrowser.js" line="+71"/>
        <source>audience</source>
        <translation>občinstvo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>creator</source>
        <translation>avtor</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>dimension</source>
        <translation>dimenzija</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>levelOfDetail</source>
        <translation>nivo podrobnosti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>license</source>
        <translation>licenca</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>perspective</source>
        <translation>pogled</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>presentation</source>
        <translation>predstavitev</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>publisher</source>
        <translation>izdajatelj</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>subject</source>
        <translation>zadeva</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>title</source>
        <translation>naslov</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Widgets</source>
        <translation>Gradniki</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1153"/>
        <location filename="../LibraryBrowserInit.js" line="+19"/>
        <source>Library Browser</source>
        <translation>Brskalnik po knjižnici</translation>
    </message>
    <message>
        <location line="-1145"/>
        <source>Icon</source>
        <translation>Ikona</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>List</source>
        <translation>Seznam</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Choose Source Folder</source>
        <translation>Izberite izvorno mapo</translation>
    </message>
    <message>
        <location line="+685"/>
        <source>Page %1 of %2</source>
        <translation>Stran %1 od %2</translation>
    </message>
    <message>
        <location line="+235"/>
        <source>Updating icons...</source>
        <translation>Posodabljam ikone...</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+219"/>
        <source>Abort</source>
        <translation>Prekini</translation>
    </message>
    <message>
        <location line="-27"/>
        <source>File:</source>
        <translation>Datoteka:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Folder:</source>
        <translation>Mapa:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>License:</source>
        <translation>Licenca:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attribute as:</source>
        <translation>Atribut kot:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Creator:</source>
        <translation>Avtor:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Updating library index:</source>
        <translation>Posodabljam index knjižnice:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>DB error</source>
        <translation>Napaka podatkovne baze</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</source>
        <translation>Vtičnik LibraryBrowser: Nemorem se povezat na podatkovno bazo.
Napaka gonilnika: %1
Napaka na baze: %2
Datoteka baze: %3
Vtičnik LibraryBrowser ne bo navoljo.</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Source removed from part library: %1</source>
        <translation>Vir odstranjen iz knjižnice: %1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Force database update.</source>
        <translation>Vsili pododobitev baze.</translation>
    </message>
    <message>
        <location line="+393"/>
        <source>&amp;Insert</source>
        <translation>&amp;Vstavi</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Edit Script File...</source>
        <translation>&amp;Uredi datoteko skripte...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Open &amp;SVG File...</source>
        <translation>Odpri &amp;SVG datoteko...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Open...</source>
        <translation>&amp;Odpri...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;Edit...</source>
        <translation>&amp;Uredi...</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>File Browser</source>
        <translation>Brskalnik datotek</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Show in %1...</source>
        <translation>P&amp;rikaži v %1...</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>&amp;Remove from Favorites</source>
        <translation>Izbriši iz pri&amp;ljubljenih</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Add to Favorites</source>
        <translation>Dodaj med &amp;priljubljene</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>&amp;Regenerate Icon</source>
        <translation>&amp;Osveži ikono</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Regenerate Icons</source>
        <translation>&amp;Osveži ikone</translation>
    </message>
    <message>
        <location filename="../LibraryBrowserInit.js" line="-11"/>
        <source>&amp;Library Browser</source>
        <translation>Brskalnik po &amp;knjižnici</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Synchronization</source>
        <translation>Sinhronizacija</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Update search index on startup</source>
        <translation>Posodobi iskalni index ob zagonu</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display Options</source>
        <translation>Nastavitve prikaza</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Icon Size:</source>
        <translation>Velikost ikone:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>View Mode:</source>
        <translation>Način pogleda:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Number of items
shown in search results:</source>
        <translation>Število predmetov,
 prikazanih v rezultatih iskanja:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Library Sources</source>
        <translation>Viri knjižni</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Add...</source>
        <translation>Dodaj...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Remove</source>
        <translation>Odstrani</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Up</source>
        <translation>Gor</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Down</source>
        <translation>Dol</translation>
    </message>
</context>
<context>
    <name>LibraryBrowserForm</name>
    <message>
        <location filename="../LibraryBrowser.ui" line="+28"/>
        <source>File System</source>
        <translation>Datotečni sistem</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation type="vanished">Značke</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Search</source>
        <translation>Išči</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Look for:</source>
        <translation>Išči za:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Clear</source>
        <translation>Počisti</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Find</source>
        <translation>Najdi</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Reset tag selection</source>
        <translation>Ponastavi izbor značk</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="vanished">o:nedoločeno</translation>
    </message>
    <message>
        <location line="+126"/>
        <source>Favorites</source>
        <translation>Priljubljeno</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Insert selected item into drawing</source>
        <translation>Vstavi izbrani predmet v risbo</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Update DB from file system</source>
        <translation>Posodobi podatkovno bazo iz datoteke</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>0</source>
        <translation>0</translation>
    </message>
</context>
</TS>
